@@ -97,7 +97,7 @@ static QString getPauseLabel(bool isPaused)
 static QString getStartLabel(bool isRunning)
 {
     if (isRunning) {
-        return "Reload";
+        return "Restart";
     }
     return "Start";
 }
@@ -124,6 +124,11 @@ void AdvancedView::update(Cluster cluster)
 #endif
     pauseButton->setText(getPauseLabel(isPaused));
     startButton->setText(getStartLabel(isRunning));
+    QString startToolTip = "";
+    if (isRunning) {
+        startToolTip = "Restart an already running minikube instance to pickup config changes.";
+    }
+    startButton->setToolTip(startToolTip);
 }
 
 void AdvancedView::setSelectedClusterName(QString cluster)
@@ -220,9 +225,9 @@ void AdvancedView::askCustom()
     QComboBox *driverComboBox = new QComboBox;
     driverComboBox->addItems({ "docker", "virtualbox", "vmware", "podman" });
 #if __linux__
-    driverComboBox->addItem("kvm2");
+    driverComboBox->addItems({ "kvm2", "qemu" });
 #elif __APPLE__
-    driverComboBox->addItems({ "hyperkit", "parallels" });
+    driverComboBox->addItems({ "hyperkit", "qemu", "parallels" });
 #else
     driverComboBox->addItem("hyperv");
 #endif
