@@ -26,6 +26,7 @@ import (
 
 	"github.com/klauspost/cpuid"
 	"golang.org/x/sys/cpu"
+	"k8s.io/minikube/pkg/minikube/localpath"
 )
 
 // RuntimeOS returns the runtime operating system
@@ -113,3 +114,18 @@ func GithubActionRunner() bool {
 	// based on https://help.github.com/en/actions/configuring-and-managing-workflows/using-environment-variables
 	return os.Getenv("GITHUB_ACTIONS") == "true"
 }
+
+// ImageCacheDir returns the path in the minikube home directory to the container image cache for the current architecture
+func ImageCacheDir() string {
+	return filepath.Join(localpath.MakeMiniPath("cache", "images"), runtime.GOARCH)
+}
+
+// KICCacheDir returns the path in the minikube home directory to the container node cache for the current architecture
+func KICCacheDir() string {
+	return filepath.Join(localpath.MakeMiniPath("cache", "kic"), runtime.GOARCH)
+}
+
+// ISOCacheDir returns the path in the minikube home directory to the virtual machine image cache for the current architecture
+func ISOCacheDir() string {
+	return filepath.Join(localpath.MakeMiniPath("cache", "iso"), runtime.GOARCH)
+}
