@@ -208,7 +208,7 @@ func Output(r cruntime.Manager, bs bootstrapper.Bootstrapper, cfg config.Cluster
 }
 
 // outputAudit displays the audit logs.
-func outputAudit(lines int) error {
+func OutputAudit(lines int) error {
 	out.Styled(style.Empty, "")
 	out.Styled(style.Empty, "==> Audit <==")
 	r, err := audit.Report(lines)
@@ -252,7 +252,7 @@ func OutputOffline(lines int, logOutput *os.File) {
 	defer out.SetOutFile(os.Stdout)
 	out.SetErrFile(logOutput)
 	defer out.SetErrFile(os.Stderr)
-	if err := outputAudit(lines); err != nil {
+	if err := OutputAudit(lines); err != nil {
 		klog.Errorf("failed to output audit logs: %v", err)
 	}
 	if err := outputLastStart(); err != nil {
