@@ -19,11 +19,11 @@ package util
 import (
 	"os"
 	"os/user"
-	"runtime"
 	"syscall"
 	"testing"
 
 	"github.com/blang/semver/v4"
+	"github.com/google/go-cmp/cmp"
 )
 
 func TestGetBinaryDownloadURL(t *testing.T) {
@@ -38,7 +38,7 @@ func TestGetBinaryDownloadURL(t *testing.T) {
 	}
 
 	for _, tt := range testData {
-		url := GetBinaryDownloadURL(tt.version, tt.platform, runtime.GOARCH)
+		url := GetBinaryDownloadURL(tt.version, tt.platform, "amd64")
 		if url != tt.expectedURL {
 			t.Fatalf("Expected '%s' but got '%s'", tt.expectedURL, url)
 		}
@@ -172,3 +172,45 @@ func TestMaybeChownDirRecursiveToMinikubeUser(t *testing.T) {
 		})
 	}
 }
+
+func TestRemoveDuplicateStrings(t *testing.T) {
+	testCases := []struct {
+		desc  string
+		slice []string
+		want  []string
+	}{
+		{
+			desc:  "NoDuplicates",
+			slice: []string{"alpha", "bravo", "charlie"},
+			want:  []string{"alpha", "bravo", "charlie"},
+		},
+		{
+			desc:  "AdjacentDuplicates",
+			slice: []string{"alpha", "bravo", "bravo", "charlie"},
+			want:  []string{"alpha", "bravo", "charlie"},
+		},
+		{
+			desc:  "NonAdjacentDuplicates",
+			slice: []string{"alpha", "bravo", "alpha", "charlie"},
+			want:  []string{"alpha", "bravo", "charlie"},
+		},
+		{
+			desc:  "MultipleDuplicates",
+			slice: []string{"alpha", "bravo", "alpha", "alpha", "charlie", "charlie", "alpha", "bravo"},
+			want:  []string{"alpha", "bravo", "charlie"},
+		},
+		{
+			desc:  "UnsortedDuplicates",
+			slice: []string{"charlie", "bravo", "alpha", "bravo"},
+			want:  []string{"charlie", "bravo", "alpha"},
+		},
+	}
+	for _, tc := range testCases {
+		t.Run(tc.desc, func(t *testing.T) {
+			got := RemoveDuplicateStrings(tc.slice)
+			if diff := cmp.Diff(got, tc.want); diff != "" {
+				t.Errorf("RemoveDuplicateStrings(%v) = %v, want: %v", tc.slice, got, tc.want)
+			}
+		})
+	}
+}
