@@ -445,11 +445,14 @@ func testPause(ctx context.Context, t *testing.T, profile string) {
 
 // Remove container-specific prefixes for naming consistency
 // for example in `docker` runtime we get this:
-// 		$ docker@minikube:~$ sudo crictl images -o json | grep dash
-// 	         "kubernetesui/dashboard:vX.X.X"
+//
+//		$ docker@minikube:~$ sudo crictl images -o json | grep dash
+//	         "kubernetesui/dashboard:vX.X.X"
+//
 // but for 'containerd' we get full name
-// 		$ docker@minikube:~$  sudo crictl images -o json | grep dash
-//        	 "docker.io/kubernetesui/dashboard:vX.X.X"
+//
+//			$ docker@minikube:~$  sudo crictl images -o json | grep dash
+//	       	 "docker.io/kubernetesui/dashboard:vX.X.X"
 func trimImageName(name string) string {
 	name = strings.TrimPrefix(name, "docker.io/")
 	name = strings.TrimPrefix(name, "localhost/")
@@ -461,7 +464,7 @@ func defaultImage(name string) bool {
 	if strings.Contains(name, ":latest") {
 		return false
 	}
-	if strings.Contains(name, "k8s.gcr.io") || strings.Contains(name, "kubernetesui") || strings.Contains(name, "storage-provisioner") {
+	if strings.Contains(name, "k8s.gcr.io") || strings.Contains(name, "registry.k8s.io") || strings.Contains(name, "kubernetesui") || strings.Contains(name, "storage-provisioner") {
 		return true
 	}
 	return false
